==> ejc-techmanagement-impl-3.0.0-20250423.013417-103-sources.jar: com/ejianc/business/techmanagement/bean/TecRegisterContentEntity.java <==
package com.ejianc.business.techmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 新技术登记子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_tec_register_content")
public class TecRegisterContentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="tec_register_id")
    private Long tecRegisterId; // 技术登记主表id
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="tec_name")
    private String tecName; // 技术名称
    @TableField(value="tec_type")
    private String tecType; // 技术类型
    @TableField(value="apply_department")
    private String applyDepartment; // 应用部门
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getTecRegisterId() {
        return tecRegisterId;
    }

    public void setTecRegisterId(Long tecRegisterId) {
        this.tecRegisterId = tecRegisterId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getTecName() {
        return tecName;
    }

    public void setTecName(String tecName) {
        this.tecName = tecName;
    }
    public String getTecType() {
        return tecType;
    }

    public void setTecType(String tecType) {
        this.tecType = tecType;
    }
    public String getApplyDepartment() {
        return applyDepartment;
    }

    public void setApplyDepartment(String applyDepartment) {
        this.applyDepartment = applyDepartment;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-techmanagement-impl-3.0.0-20251127.061515-111-sources.jar: com/ejianc/business/techmanagement/bean/TecRegisterContentEntity.java <==
package com.ejianc.business.techmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 新技术登记子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_tec_register_content")
public class TecRegisterContentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="tec_register_id")
    private Long tecRegisterId; // 技术登记主表id
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="tec_name")
    private String tecName; // 技术名称
    @TableField(value="tec_type")
    private String tecType; // 技术类型
    @TableField(value="apply_department")
    private String applyDepartment; // 应用部门
    @TableField(value="memo")
    private String memo; // 备注

    @TableField(value = "apply_site_id")
    private Long applySiteId;
    @TableField(value = "apply_site_name")
    private String applySiteName;;


    public Long getApplySiteId() {
        return applySiteId;
    }

    public void setApplySiteId(Long applySiteId) {
        this.applySiteId = applySiteId;
    }

    public String getApplySiteName() {
        return applySiteName;
    }

    public void setApplySiteName(String applySiteName) {
        this.applySiteName = applySiteName;
    }

    public Long getTecRegisterId() {
        return tecRegisterId;
    }

    public void setTecRegisterId(Long tecRegisterId) {
        this.tecRegisterId = tecRegisterId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getTecName() {
        return tecName;
    }

    public void setTecName(String tecName) {
        this.tecName = tecName;
    }
    public String getTecType() {
        return tecType;
    }

    public void setTecType(String tecType) {
        this.tecType = tecType;
    }
    public String getApplyDepartment() {
        return applyDepartment;
    }

    public void setApplyDepartment(String applyDepartment) {
        this.applyDepartment = applyDepartment;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
